package com.ynet.life.credit.business;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.credit.dao.SequenceNoGetter;
import com.ynet.life.credit.dao.SqlExcutor;
import com.ynet.life.credit.dao.SqlQueryTester;
import com.ynet.life.credit.util.IOUtil;
import com.ynet.life.credit.util.TimeUtils;
import com.ynet.life.credit.vo.input.CreditDetailVo;
import com.ynet.life.credit.vo.output.CreditOutJsonVo;
import com.ynet.life.credit.vo.output.CreditOutListVo;
import com.ynet.life.credit.vo.output.CreditOutWhenCreditVo;
import com.ynet.life.credit.vo.output.OutBaseVo;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.util.PropertiesFile;
import edu.emory.mathcs.backport.java.util.Arrays;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.UUID;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_credit_business.jar:com/ynet/life/credit/business/GetCreditICExcutor.class */
public class GetCreditICExcutor extends BaseApiExcutor<CreditOutWhenCreditVo> {
    public static String[] error_table = {"mList", "tList", "fList", "bList", "iList", "nList", "jList", "zList", "sList", "hList", "cList", "rList", "kList"};
    private static String CREDIT_COMPONENT = "【【征信获取征信报告接口】】";

    public String execore(CreditDetailVo vo) throws Exception {
        String result;
        Long timeStamp1 = TimeUtils.getNowTimeStamp();
        String nowTime = TimeUtils.getNowTime("yyyyMMddhhmmss");
        List<String> sqlList = new ArrayList<>();
        if (StringUtils.isBlank(vo.getFCI_CORNO())) {
            throw new TranFailException("400", "缺少参数", false);
        }
        vo.setBusiSeq(UUID.randomUUID().toString());
        Properties bankDBSourceProperties = PropertiesFile.getProperties("/properties/creditApiPath.properties");
        String urlApi = bankDBSourceProperties.getProperty("creditBaseUrl");
        String productMode = bankDBSourceProperties.getProperty("productMode");
        String jsonFilePath = bankDBSourceProperties.getProperty("jsonFilePath");
        vo.setApiAddr(urlApi);
        GENELog.log(CREDIT_COMPONENT, GENELog.INFO, 0, "请求参数==" + vo.toString());
        Arrays.asList(new String[]{"busiSeq", "cardType", "cardCode", "wsUser"});
        if ("false".equals(productMode)) {
            result = IOUtil.readLocalFile(jsonFilePath);
        } else {
            result = getICInfo(vo, urlApi);
        }
        Long timeStamp2 = TimeUtils.getNowTimeStamp();
        String reqCost = String.valueOf(timeStamp2.longValue() - timeStamp1.longValue());
        new CreditOutJsonVo();
        for (int i = 0; i < error_table.length; i++) {
            result = result.replaceAll("\"" + error_table[i] + "\"", "\"" + error_table[i].toLowerCase() + "\"");
        }
        String corno = vo.getFCI_CORNO();
        CreditOutJsonVo out = (CreditOutJsonVo) parseStringToObject(result, CreditOutJsonVo.class);
        if ("200".equals(out.getReponseCode())) {
            out.setD2_alldata(result);
            CreditOutListVo listout = (CreditOutListVo) parseStringToObject(result, CreditOutListVo.class);
            SequenceNoGetter seqGeter = new SequenceNoGetter();
            listout.setSeq_no(seqGeter.execute("creditDetailNo"));
            listout.setFCI_CORNO(corno);
            StringBuilder sb = new StringBuilder("select * from ");
            out.getClass();
            String testsql = sb.append("credit_corinf_snap where fci_corno = '").append(corno).append("'").toString();
            String seqNo = new SqlQueryTester(testsql).isHaveData();
            out.setD2_create_time(nowTime);
            if (StringUtils.isBlank(seqNo)) {
                out.setSeq_no(seqGeter.execute("creditDetailNo"));
                out.setFCI_CORNO(corno);
                sqlList.addAll(out.toInsertSqlString());
            } else {
                out.setSeq_no(seqNo);
                out.setFCI_CORNO(corno);
                sqlList.addAll(out.toUpdateSqlString());
            }
            sqlList.addAll(listout.toListSqlString());
            String respCost = String.valueOf(TimeUtils.getNowTimeStamp().longValue() - timeStamp2.longValue());
            out.setBusiSeq(vo.getBusiSeq());
            out.setFCI_CORNO(corno);
            out.setReq_data(vo.toString());
            out.setReq_api(vo.getApiAddr());
            out.setReq_cost_time(reqCost);
            out.setResp_cost_time(respCost);
            out.setOper_user(vo.getUserId());
            OutBaseVo baseVo = new OutBaseVo();
            BeanUtils.copyProperties(baseVo, out);
            sqlList.add(baseVo.toLogSqlString());
            GENELog.log(CREDIT_COMPONENT, GENELog.INFO, 0, "执行脚本==" + sqlList.toString());
            SqlExcutor sqlExcutor = new SqlExcutor();
            sqlExcutor.setBatchInsertList(sqlList);
            sqlExcutor.execute();
            if (StringUtils.isBlank(out.getReponseCode()) || "400".equals(out.getReponseCode())) {
                throw null;
            }
            return result;
        }
        throw new TranFailException(out.getReponseCode(), out.getReponseMsg(), false);
    }

    @Override // com.ynet.life.credit.business.BaseApiExcutor
    public String execute(Context context) throws GENEException {
        KeyedCollection coll = context.getDataElement();
        String result = "";
        try {
            CreditDetailVo vo = new CreditDetailVo().contextToInBaseVo(coll);
            result = execore(vo);
        } catch (Exception e) {
            GENELog.log(GENEConstance.GENE_ACTION, GENELog.ERROR, 0, e.getMessage());
            e.printStackTrace();
            return "";
        } catch (TranFailException e2) {
            String language = (String) getSessionCtx(context).get("session_language");
            e2.setShowMessage(LifeStandard.getResouceDisplayAt(e2.getShowMessage(), language));
            context.put("GENEException", (Object) null);
        }
        return result;
    }
}
